@@ -141,7 +141,7 @@ inline KRB5TicketFlags operator&(KRB5TicketFlags a, KRB5TicketFlags b)
 typedef TQValueList<uid_t> UserList;
 typedef TQValueList<gid_t> GroupList;
 
-class LDAPCredentials
+class KDE_EXPORT LDAPCredentials
 {
 	public:
 		LDAPCredentials();
@@ -157,7 +157,7 @@ class LDAPCredentials
 };
 
 // PRIVATE
-class LDAPRealmConfig
+class KDE_EXPORT LDAPRealmConfig
 {
 	public:
 		TQString name;
@@ -176,7 +176,7 @@ class LDAPRealmConfig
 };
 
 // PRIVATE
-class LDAPCertConfig
+class KDE_EXPORT LDAPCertConfig
 {
 	public:
 		bool generate_certs;
@@ -197,7 +197,7 @@ class LDAPCertConfig
 };
 
 // PRIVATE
-class LDAPPamConfig
+class KDE_EXPORT LDAPPamConfig
 {
 	public:
 		LDAPPamConfig();
@@ -211,7 +211,7 @@ class LDAPPamConfig
 };
 
 // PRIVATE
-class LDAPClientRealmConfig
+class KDE_EXPORT LDAPClientRealmConfig
 {
 	public:
 		bool enable_bonding;
@@ -234,7 +234,7 @@ class LDAPClientRealmConfig
 
 typedef TQMap<TQString, LDAPRealmConfig> LDAPRealmConfigList;
 
-class LDAPUserInfo
+class KDE_EXPORT LDAPUserInfo
 {
 	public:
 		LDAPUserInfo();
@@ -314,7 +314,7 @@ class LDAPUserInfo
 		TQString notes;
 };
 
-class LDAPGroupInfo
+class KDE_EXPORT LDAPGroupInfo
 {
 	public:
 		LDAPGroupInfo();
@@ -331,7 +331,7 @@ class LDAPGroupInfo
 		TQStringList userlist;
 };
 
-class LDAPMachineInfo
+class KDE_EXPORT LDAPMachineInfo
 {
 	public:
 		LDAPMachineInfo();
@@ -348,7 +348,7 @@ class LDAPMachineInfo
 		LDAPKRB5Flags status;		// Default is 126 [KRB5_MACHINE_ACCOUNT_DEFAULT]
 };
 
-class LDAPServiceInfo
+class KDE_EXPORT LDAPServiceInfo
 {
 	public:
 		LDAPServiceInfo();
@@ -366,7 +366,7 @@ class LDAPServiceInfo
 		LDAPKRB5Flags status;		// Default is 126 [KRB5_SERVICE_PRINCIPAL_DEFAULT]
 };
 
-class LDAPTDEBuiltinsInfo
+class KDE_EXPORT LDAPTDEBuiltinsInfo
 {
 	public:
 		LDAPTDEBuiltinsInfo();
@@ -380,7 +380,7 @@ class LDAPTDEBuiltinsInfo
 		TQString builtinStandardUserGroup;
 };
 
-class LDAPMasterReplicationMapping
+class KDE_EXPORT LDAPMasterReplicationMapping
 {
 	public:
 		LDAPMasterReplicationMapping();
@@ -393,7 +393,7 @@ class LDAPMasterReplicationMapping
 
 typedef TQValueList<LDAPMasterReplicationMapping> LDAPMasterReplicationMap;
 
-class LDAPMasterReplicationInfo
+class KDE_EXPORT LDAPMasterReplicationInfo
 {
 	public:
 		LDAPMasterReplicationInfo();
@@ -414,7 +414,7 @@ class LDAPMasterReplicationInfo
 		bool replicate_olcGlobal;
 };
 
-class KerberosTicketInfo
+class KDE_EXPORT KerberosTicketInfo
 {
 	public:
 		KerberosTicketInfo();
@@ -445,7 +445,7 @@ typedef TQValueList<KerberosTicketInfo> KerberosTicketInfoList;
 
 class PtyProcess;
 
-class LDAPManager : public TQObject {
+class KDE_EXPORT LDAPManager : public TQObject {
 	Q_OBJECT
 
 	public:
